@@ -120,10 +120,11 @@ sub my_options {
 	    'black',
 	    'Color to use for lines connecting discontinuous pieces of the feature.'],
 	record_label_positions => [
-	    'boolean',
+	    'integer',
 	    undef,
 	    'If true, remember the coordinates of the glyph label and return it',
-	    'by calling $panel->key_boxes.'
+	    'by calling $panel->key_boxes. If -1, then remember coordinates, but',
+	    "don't actually draw the label",
 	]
     }
 
@@ -457,6 +458,7 @@ sub draw_label {
   my ($gd,$left,$top,$partno,$total_parts) = @_;
 
   my $label = $self->label or return;
+  local $self->{default_opacity} = 1;
 
   my $x    = $self->left + $left; # valid for both "top" and "left" because the left-hand side is defined by pad_left
   my $font = $self->labelfont;
@@ -490,15 +492,21 @@ sub draw_label {
 sub render_label {
     my $self = shift;
     my ($gd,$font,$x,$y,$label,$is_legend) = @_;
-    if(!$is_legend){$gd->string($font,$x,$y,$label,$self->labelcolor);}
+    my $rlp = $self->record_label_positions;
+    unless ($rlp || $is_legend)
+    {
+	$gd->string($font,$x,$y,$label,$self->labelcolor);
+    }
     $self->panel->add_key_box($self,$label,$x,$y)
-	if $self->record_label_positions;
+	if $rlp
 }
 
 sub draw_description {
   my $self = shift;
   my ($gd,$dx,$dy,$partno,$total_parts) = @_;
   my $label = $self->description or return;
+
+  local $self->{default_opacity} = 1;
   my ($left,$top,$right,$bottom) = $self->bounds($dx,$dy);
   $bottom  += $self->pad_bottom;
   $bottom  -= $self->labelheight;
@@ -516,6 +524,9 @@ sub draw_part_labels {
   my ($gd,$left,$top,$partno,$total_parts) = @_;
   return unless $self->{level} == 0;
   my @p = $self->parts or return;
+
+  local $self->{default_opacity} = 1;
+
   @p > 1 or return;
   @p = reverse @p if $self->flip;
 
